==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QPixmap_shell.h <==
#ifndef QPIXMAP_SHELL_H
#define QPIXMAP_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qpixmap.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcolor.h>
#include <QtGui/qimage.h>
#include <QtGui/qimagereader.h>
#include <QtGui/qimagewriter.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#include <QtJambiGui/hashes.h>
#include <QtJambi/RegistryAPI>


class QPixmap_shell : public QPixmap, public QtJambiShellInterface
{
public:
    QPixmap_shell();
    QPixmap_shell(const QPixmap& arg__1);
    QPixmap_shell(const QSize& arg__1);
    QPixmap_shell(const QString& fileName0, const char* format1 = nullptr, Qt::ImageConversionFlags flags2 = Qt::AutoColor);
    QPixmap_shell(const char*const * xpm0);
    QPixmap_shell(int w0, int h1);
    ~QPixmap_shell() override;

    void initPainter(QPainter* painter0) const override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QPaintEngine* paintEngine() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    QPainter* sharedPainter() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPixmap_access : public QPixmap
{
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_paintEngine_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    jobject __qt_sharedPainter_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPIXMAP_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QPixmap_shell.h <==
#ifndef QPIXMAP_SHELL_H
#define QPIXMAP_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qpixmap.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcolor.h>
#include <QtGui/qimage.h>
#include <QtGui/qimagereader.h>
#include <QtGui/qimagewriter.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#include <QtJambiGui/hashes.h>
#include <QtJambi/RegistryAPI>


class QPixmap_shell : public QPixmap, public QtJambiShellInterface
{
public:
    QPixmap_shell();
    QPixmap_shell(const QPixmap& arg__1);
    QPixmap_shell(const QSize& arg__1);
    QPixmap_shell(const QString& fileName0, const char* format1 = nullptr, Qt::ImageConversionFlags flags2 = Qt::AutoColor);
    QPixmap_shell(const char*const * xpm0);
    QPixmap_shell(int w0, int h1);
    ~QPixmap_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QPixmap_oshell;
};


class QPixmap_oshell : public QPixmap_shell
{
public:
    using QPixmap_shell::QPixmap_shell;
    ~QPixmap_oshell() override;
    void initPainter(QPainter* painter0) const override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QPaintEngine* paintEngine() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    QPainter* sharedPainter() const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPixmap_access : public QPixmap
{
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_paintEngine_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    jobject __qt_sharedPainter_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPIXMAP_SHELL_H
